@@ -5,23 +5,29 @@
  *
  * @package PhpMyAdmin
  */
-require_once 'libraries/common.inc.php';
-require_once 'libraries/error_report.lib.php';
-require_once 'libraries/user_preferences.lib.php';
+use PhpMyAdmin\ErrorReport;
+use PhpMyAdmin\Message;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\UserPreferences;
+use PhpMyAdmin\Utils\HttpRequest;
 
-if (!isset($_REQUEST['exception_type'])
-    ||!in_array($_REQUEST['exception_type'], array('js', 'php'))
+require_once 'libraries/common.inc.php';
+
+if (!isset($_POST['exception_type'])
+    ||!in_array($_POST['exception_type'], array('js', 'php'))
 ) {
     die('Oops, something went wrong!!');
 }
 
-$response = PMA_Response::getInstance();
+$response = Response::getInstance();
 
-if (isset($_REQUEST['send_error_report'])
-    && ($_REQUEST['send_error_report'] == true
-    || $_REQUEST['send_error_report'] == '1')
+$errorReport = new ErrorReport(new HttpRequest());
+
+if (isset($_POST['send_error_report'])
+    && ($_POST['send_error_report'] == true
+    || $_POST['send_error_report'] == '1')
 ) {
-    if ($_REQUEST['exception_type'] == 'php') {
+    if ($_POST['exception_type'] == 'php') {
         /**
          * Prevent infinite error submission.
          * Happens in case error submissions fails.
@@ -35,7 +41,6 @@ if (isset($_REQUEST['send_error_report'])
         ) {
             $_SESSION['error_subm_count'] = 0;
             $_SESSION['prev_errors'] = '';
-             $response = PMA_Response::getInstance();
             $response->addJSON('_stopErrorReportLoop', '1');
         } else {
             $_SESSION['prev_error_subm_time'] = time();
@@ -46,10 +51,10 @@ if (isset($_REQUEST['send_error_report'])
             );
         }
     }
-    $reportData = PMA_getReportData($_REQUEST['exception_type']);
+    $reportData = $errorReport->getData($_POST['exception_type']);
     // report if and only if there were 'actual' errors.
     if (count($reportData) > 0) {
-        $server_response = PMA_sendErrorReport($reportData);
+        $server_response = $errorReport->send($reportData);
         if ($server_response === false) {
             $success = false;
         } else {
@@ -60,8 +65,8 @@ if (isset($_REQUEST['send_error_report'])
 
         /* Message to show to the user */
         if ($success) {
-            if ((isset($_REQUEST['automatic'])
-                && $_REQUEST['automatic'] === "true")
+            if ((isset($_POST['automatic'])
+                && $_POST['automatic'] === "true")
                 || $GLOBALS['cfg']['SendErrorReports'] == 'always'
             ) {
                 $msg = __(
@@ -86,45 +91,45 @@ if (isset($_REQUEST['send_error_report'])
 
         /* Create message object */
         if ($success) {
-            $msg = PMA_Message::notice($msg);
+            $msg = Message::notice($msg);
         } else {
-            $msg = PMA_Message::error($msg);
+            $msg = Message::error($msg);
         }
 
         /* Add message to response */
         if ($response->isAjax()) {
-            if ($_REQUEST['exception_type'] == 'js') {
+            if ($_POST['exception_type'] == 'js') {
                 $response->addJSON('message', $msg);
             } else {
                 $response->addJSON('_errSubmitMsg', $msg);
             }
-        } elseif ($_REQUEST['exception_type'] == 'php') {
+        } elseif ($_POST['exception_type'] == 'php') {
             $jsCode = 'PMA_ajaxShowMessage("<div class=\"error\">'
                     . $msg
                     . '</div>", false);';
             $response->getFooter()->getScripts()->addCode($jsCode);
         }
 
-        if ($_REQUEST['exception_type'] == 'php') {
+        if ($_POST['exception_type'] == 'php') {
             // clear previous errors & save new ones.
             $GLOBALS['error_handler']->savePreviousErrors();
         }
 
         /* Persist always send settings */
-        if (isset($_REQUEST['always_send'])
-            && $_REQUEST['always_send'] === "true"
+        if (isset($_POST['always_send'])
+            && $_POST['always_send'] === "true"
         ) {
-            PMA_persistOption("SendErrorReports", "always", "ask");
+            $userPreferences = new UserPreferences();
+            $userPreferences->persistOption("SendErrorReports", "always", "ask");
         }
     }
-} elseif (! empty($_REQUEST['get_settings'])) {
+} elseif (! empty($_POST['get_settings'])) {
     $response->addJSON('report_setting', $GLOBALS['cfg']['SendErrorReports']);
 } else {
-    if ($_REQUEST['exception_type'] == 'js') {
-        $response->addHTML(PMA_getErrorReportForm());
+    if ($_POST['exception_type'] == 'js') {
+        $response->addHTML($errorReport->getForm());
     } else {
         // clear previous errors & save new ones.
         $GLOBALS['error_handler']->savePreviousErrors();
     }
 }
-?>
