@@ -12,19 +12,24 @@
  * @package PhpMyAdmin
  */
 
+use PhpMyAdmin\Core;
+use PhpMyAdmin\File;
+use PhpMyAdmin\InsertEdit;
+use PhpMyAdmin\Message;
+use PhpMyAdmin\Plugins\IOTransformationsPlugin;
+use PhpMyAdmin\Relation;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Table;
+use PhpMyAdmin\Transformations;
+use PhpMyAdmin\Util;
+
 /**
  * Gets some core libraries
  */
 require_once 'libraries/common.inc.php';
 
-/**
- * functions implementation for this script
- */
-require_once 'libraries/insert_edit.lib.php';
-require_once 'libraries/transformations.lib.php';
-
 // Check parameters
-PMA_Util::checkParameters(array('db', 'table', 'goto'));
+Util::checkParameters(array('db', 'table', 'goto'));
 
 $GLOBALS['dbi']->selectDb($GLOBALS['db']);
 
@@ -33,7 +38,7 @@ $GLOBALS['dbi']->selectDb($GLOBALS['db']);
  */
 $goto_include = false;
 
-$response = PMA_Response::getInstance();
+$response = Response::getInstance();
 $header = $response->getHeader();
 $scripts = $header->getScripts();
 $scripts->addFile('makegrid.js');
@@ -42,35 +47,39 @@ $scripts->addFile('sql.js');
 $scripts->addFile('indexes.js');
 $scripts->addFile('gis_data_editor.js');
 
+$relation = new Relation();
+
+$insertEdit = new InsertEdit($GLOBALS['dbi']);
+
 // check whether insert row mode, if so include tbl_change.php
-PMA_isInsertRow();
+$insertEdit->isInsertRow();
 
 $after_insert_actions = array('new_insert', 'same_insert', 'edit_next');
-if (isset($_REQUEST['after_insert'])
-    && in_array($_REQUEST['after_insert'], $after_insert_actions)
+if (isset($_POST['after_insert'])
+    && in_array($_POST['after_insert'], $after_insert_actions)
 ) {
-    $url_params['after_insert'] = $_REQUEST['after_insert'];
-    if (isset($_REQUEST['where_clause'])) {
-        foreach ($_REQUEST['where_clause'] as $one_where_clause) {
-            if ($_REQUEST['after_insert'] == 'same_insert') {
+    $url_params['after_insert'] = $_POST['after_insert'];
+    if (isset($_POST['where_clause'])) {
+        foreach ($_POST['where_clause'] as $one_where_clause) {
+            if ($_POST['after_insert'] == 'same_insert') {
                 $url_params['where_clause'][] = $one_where_clause;
-            } elseif ($_REQUEST['after_insert'] == 'edit_next') {
-                PMA_setSessionForEditNext($one_where_clause);
+            } elseif ($_POST['after_insert'] == 'edit_next') {
+                $insertEdit->setSessionForEditNext($one_where_clause);
             }
         }
     }
 }
 //get $goto_include for different cases
-$goto_include = PMA_getGotoInclude($goto_include);
+$goto_include = $insertEdit->getGotoInclude($goto_include);
 
 // Defines the url to return in case of failure of the query
-$err_url = PMA_getErrorUrl($url_params);
+$err_url = $insertEdit->getErrorUrl($url_params);
 
 /**
  * Prepares the update/insert of a row
  */
 list($loop_array, $using_key, $is_insert, $is_insertignore)
-    = PMA_getParamsForUpdateOrInsert();
+    = $insertEdit->getParamsForUpdateOrInsert();
 
 $query = array();
 $value_sets = array();
@@ -123,11 +132,8 @@ $gis_from_wkb_functions = array(
     'MPolyFromWKB',
 );
 
-// to create an object of PMA_File class
-require_once './libraries/File.class.php';
-
 //if some posted fields need to be transformed.
-$mime_map = PMA_getMIME($GLOBALS['db'], $GLOBALS['table']);
+$mime_map = Transformations::getMIME($GLOBALS['db'], $GLOBALS['table']);
 if ($mime_map === false) {
     $mime_map = array();
 }
@@ -138,7 +144,7 @@ $row_skipped = false;
 $unsaved_values = array();
 foreach ($loop_array as $rownumber => $where_clause) {
     // skip fields to be ignored
-    if (! $using_key && isset($_REQUEST['insert_ignore_' . $where_clause])) {
+    if (! $using_key && isset($_POST['insert_ignore_' . $where_clause])) {
         continue;
     }
 
@@ -147,43 +153,47 @@ foreach ($loop_array as $rownumber => $where_clause) {
 
     // Map multi-edit keys to single-level arrays, dependent on how we got the fields
     $multi_edit_columns
-        = isset($_REQUEST['fields']['multi_edit'][$rownumber])
-        ? $_REQUEST['fields']['multi_edit'][$rownumber]
+        = isset($_POST['fields']['multi_edit'][$rownumber])
+        ? $_POST['fields']['multi_edit'][$rownumber]
         : array();
     $multi_edit_columns_name
-        = isset($_REQUEST['fields_name']['multi_edit'][$rownumber])
-        ? $_REQUEST['fields_name']['multi_edit'][$rownumber]
+        = isset($_POST['fields_name']['multi_edit'][$rownumber])
+        ? $_POST['fields_name']['multi_edit'][$rownumber]
         : array();
     $multi_edit_columns_prev
-        = isset($_REQUEST['fields_prev']['multi_edit'][$rownumber])
-        ? $_REQUEST['fields_prev']['multi_edit'][$rownumber]
+        = isset($_POST['fields_prev']['multi_edit'][$rownumber])
+        ? $_POST['fields_prev']['multi_edit'][$rownumber]
         : null;
     $multi_edit_funcs
-        = isset($_REQUEST['funcs']['multi_edit'][$rownumber])
-        ? $_REQUEST['funcs']['multi_edit'][$rownumber]
+        = isset($_POST['funcs']['multi_edit'][$rownumber])
+        ? $_POST['funcs']['multi_edit'][$rownumber]
         : null;
     $multi_edit_salt
-        = isset($_REQUEST['salt']['multi_edit'][$rownumber])
-        ? $_REQUEST['salt']['multi_edit'][$rownumber]
+        = isset($_POST['salt']['multi_edit'][$rownumber])
+        ? $_POST['salt']['multi_edit'][$rownumber]
         :null;
     $multi_edit_columns_type
-        = isset($_REQUEST['fields_type']['multi_edit'][$rownumber])
-        ? $_REQUEST['fields_type']['multi_edit'][$rownumber]
+        = isset($_POST['fields_type']['multi_edit'][$rownumber])
+        ? $_POST['fields_type']['multi_edit'][$rownumber]
         : null;
     $multi_edit_columns_null
-        = isset($_REQUEST['fields_null']['multi_edit'][$rownumber])
-        ? $_REQUEST['fields_null']['multi_edit'][$rownumber]
+        = isset($_POST['fields_null']['multi_edit'][$rownumber])
+        ? $_POST['fields_null']['multi_edit'][$rownumber]
         : null;
     $multi_edit_columns_null_prev
-        = isset($_REQUEST['fields_null_prev']['multi_edit'][$rownumber])
-        ? $_REQUEST['fields_null_prev']['multi_edit'][$rownumber]
+        = isset($_POST['fields_null_prev']['multi_edit'][$rownumber])
+        ? $_POST['fields_null_prev']['multi_edit'][$rownumber]
         : null;
     $multi_edit_auto_increment
-        = isset($_REQUEST['auto_increment']['multi_edit'][$rownumber])
-        ? $_REQUEST['auto_increment']['multi_edit'][$rownumber]
+        = isset($_POST['auto_increment']['multi_edit'][$rownumber])
+        ? $_POST['auto_increment']['multi_edit'][$rownumber]
+        : null;
+    $multi_edit_virtual
+        = isset($_POST['virtual']['multi_edit'][$rownumber])
+        ? $_POST['virtual']['multi_edit'][$rownumber]
         : null;
 
-    // When a select field is nullified, it's not present in $_REQUEST
+    // When a select field is nullified, it's not present in $_POST
     // so initialize it; this way, the foreach($multi_edit_columns) will process it
     foreach ($multi_edit_columns_name as $key => $val) {
         if (! isset($multi_edit_columns[$key])) {
@@ -200,7 +210,7 @@ foreach ($loop_array as $rownumber => $where_clause) {
         // Note: $key is an md5 of the fieldname. The actual fieldname is
         // available in $multi_edit_columns_name[$key]
 
-        $file_to_insert = new PMA_File();
+        $file_to_insert = new File();
         $file_to_insert->checkTblChangeForm($key, $rownumber);
 
         $possibly_uploaded_val = $file_to_insert->getContent();
@@ -211,63 +221,66 @@ foreach ($loop_array as $rownumber => $where_clause) {
         if (!empty($mime_map[$column_name])
             && !empty($mime_map[$column_name]['input_transformation'])
         ) {
-            $filename = 'libraries/plugins/transformations/'
+            $filename = 'libraries/classes/Plugins/Transformations/'
                 . $mime_map[$column_name]['input_transformation'];
             if (is_file($filename)) {
-                include_once $filename;
-                $classname = PMA_getTransformationClassName(
-                    $mime_map[$column_name]['input_transformation']
-                );
-                $transformation_plugin = new $classname();
-                $transformation_options = PMA_Transformation_getOptions(
-                    $mime_map[$column_name]['input_transformation_options']
-                );
-                $current_value = $transformation_plugin->applyTransformation(
-                    $current_value, $transformation_options
-                );
-                // check if transformation was successful or not
-                // and accordingly set error messages & insert_fail
-                if (method_exists($transformation_plugin, 'isSuccess')
-                    && !$transformation_plugin->isSuccess()
-                ) {
-                    $insert_fail = true;
-                    $row_skipped = true;
-                    $insert_errors[] = sprintf(
-                        __('Row: %1$s, Column: %2$s, Error: %3$s'),
-                        $rownumber, $column_name,
-                        $transformation_plugin->getError()
+                $classname = Transformations::getClassName($filename);
+                if (class_exists($classname)) {
+                    /** @var IOTransformationsPlugin $transformation_plugin */
+                    $transformation_plugin = new $classname();
+                    $transformation_options = Transformations::getOptions(
+                        $mime_map[$column_name]['input_transformation_options']
                     );
+                    $current_value = $transformation_plugin->applyTransformation(
+                        $current_value, $transformation_options
+                    );
+                    // check if transformation was successful or not
+                    // and accordingly set error messages & insert_fail
+                    if (method_exists($transformation_plugin, 'isSuccess')
+                        && !$transformation_plugin->isSuccess()
+                    ) {
+                        $insert_fail = true;
+                        $row_skipped = true;
+                        $insert_errors[] = sprintf(
+                            __('Row: %1$s, Column: %2$s, Error: %3$s'),
+                            $rownumber, $column_name,
+                            $transformation_plugin->getError()
+                        );
+                    }
                 }
             }
         }
 
         if ($file_to_insert->isError()) {
-            $message .= $file_to_insert->getError();
+            $insert_errors[] = $file_to_insert->getError();
         }
         // delete $file_to_insert temporary variable
         $file_to_insert->cleanUp();
 
-        $current_value = PMA_getCurrentValueForDifferentTypes(
+        $current_value = $insertEdit->getCurrentValueForDifferentTypes(
             $possibly_uploaded_val, $key, $multi_edit_columns_type,
             $current_value, $multi_edit_auto_increment,
             $rownumber, $multi_edit_columns_name, $multi_edit_columns_null,
             $multi_edit_columns_null_prev, $is_insert,
-            $using_key, $where_clause, $table
+            $using_key, $where_clause, $table, $multi_edit_funcs
         );
 
-        $current_value_as_an_array = PMA_getCurrentValueAsAnArrayForMultipleEdit(
+        $current_value_as_an_array = $insertEdit->getCurrentValueAsAnArrayForMultipleEdit(
             $multi_edit_funcs,
             $multi_edit_salt, $gis_from_text_functions, $current_value,
             $gis_from_wkb_functions, $func_optional_param, $func_no_param, $key
         );
 
-        list($query_values, $query_fields)
-            = PMA_getQueryValuesForInsertAndUpdateInMultipleEdit(
-                $multi_edit_columns_name, $multi_edit_columns_null, $current_value,
-                $multi_edit_columns_prev, $multi_edit_funcs, $is_insert,
-                $query_values, $query_fields, $current_value_as_an_array,
-                $value_sets, $key, $multi_edit_columns_null_prev
-            );
+        if (! isset($multi_edit_virtual) || ! isset($multi_edit_virtual[$key])) {
+            list($query_values, $query_fields)
+                = $insertEdit->getQueryValuesForInsertAndUpdateInMultipleEdit(
+                    $multi_edit_columns_name, $multi_edit_columns_null,
+                    $current_value, $multi_edit_columns_prev, $multi_edit_funcs,
+                    $is_insert, $query_values, $query_fields,
+                    $current_value_as_an_array, $value_sets, $key,
+                    $multi_edit_columns_null_prev
+                );
+        }
         if (isset($multi_edit_columns_null[$key])) {
             $multi_edit_columns[$key] = null;
         }
@@ -283,37 +296,42 @@ foreach ($loop_array as $rownumber => $where_clause) {
             $value_sets[] = implode(', ', $query_values);
         } else {
             // build update query
-            $query[] = 'UPDATE ' . PMA_Util::backquote($GLOBALS['db'])
-                . '.' . PMA_Util::backquote($GLOBALS['table'])
+            $query[] = 'UPDATE ' . Util::backquote($GLOBALS['table'])
                 . ' SET ' . implode(', ', $query_values)
                 . ' WHERE ' . $where_clause
-                . ($_REQUEST['clause_is_unique'] ? '' : ' LIMIT 1');
+                . ($_POST['clause_is_unique'] ? '' : ' LIMIT 1');
         }
     }
 } // end foreach ($loop_array as $where_clause)
-unset($multi_edit_columns_name, $multi_edit_columns_prev, $multi_edit_funcs,
+unset(
+    $multi_edit_columns_name, $multi_edit_columns_prev, $multi_edit_funcs,
     $multi_edit_columns_type, $multi_edit_columns_null, $func_no_param,
     $multi_edit_auto_increment, $current_value_as_an_array, $key, $current_value,
     $loop_array, $where_clause, $using_key,  $multi_edit_columns_null_prev,
-    $insert_fail);
+    $insert_fail
+);
 
 // Builds the sql query
 if ($is_insert && count($value_sets) > 0) {
-    $query = PMA_buildSqlQuery($is_insertignore, $query_fields, $value_sets);
-} elseif (empty($query) && ! isset($_REQUEST['preview_sql']) && !$row_skipped) {
+    $query = $insertEdit->buildSqlQuery($is_insertignore, $query_fields, $value_sets);
+} elseif (empty($query) && ! isset($_POST['preview_sql']) && !$row_skipped) {
     // No change -> move back to the calling script
     //
     // Note: logic passes here for inline edit
-    $message = PMA_Message::success(__('No change'));
+    $message = Message::success(__('No change'));
+    // Avoid infinite recursion
+    if ($goto_include == 'tbl_replace.php') {
+        $goto_include = 'tbl_change.php';
+    }
     $active_page = $goto_include;
-    include '' . PMA_securePath($goto_include);
+    include '' . Core::securePath($goto_include);
     exit;
 }
 unset($multi_edit_columns, $is_insertignore);
 
 // If there is a request for SQL previewing.
-if (isset($_REQUEST['preview_sql'])) {
-    PMA_previewSQL($query);
+if (isset($_POST['preview_sql'])) {
+    Core::previewSQL($query);
 }
 
 /**
@@ -322,28 +340,32 @@ if (isset($_REQUEST['preview_sql'])) {
  */
 list ($url_params, $total_affected_rows, $last_messages, $warning_messages,
     $error_messages, $return_to_sql_query)
-        = PMA_executeSqlQuery($url_params, $query);
+        = $insertEdit->executeSqlQuery($url_params, $query);
 
 if ($is_insert && (count($value_sets) > 0 || $row_skipped)) {
-    $message = PMA_Message::getMessageForInsertedRows($total_affected_rows);
+    $message = Message::getMessageForInsertedRows(
+        $total_affected_rows
+    );
     $unsaved_values = array_values($unsaved_values);
 } else {
-    $message = PMA_Message::getMessageForAffectedRows($total_affected_rows);
+    $message = Message::getMessageForAffectedRows(
+        $total_affected_rows
+    );
 }
 if ($row_skipped) {
     $goto_include = 'tbl_change.php';
-    $message->addMessages($insert_errors, '<br />');
+    $message->addMessagesString($insert_errors, '<br />');
     $message->isError(true);
 }
 
 $message->addMessages($last_messages, '<br />');
 
 if (! empty($warning_messages)) {
-    $message->addMessages($warning_messages, '<br />');
+    $message->addMessagesString($warning_messages, '<br />');
     $message->isError(true);
 }
 if (! empty($error_messages)) {
-    $message->addMessages($error_messages);
+    $message->addMessagesString($error_messages);
     $message->isError(true);
 }
 unset(
@@ -362,39 +384,36 @@ if ($response->isAjax() && ! isset($_POST['ajax_page_request'])) {
      * If we are in grid editing, we need to process the relational and
      * transformed fields, if they were edited. After that, output the correct
      * link/transformed value and exit
-     *
-     * Logic taken from libraries/DisplayResults.class.php
      */
+    if (isset($_POST['rel_fields_list']) && $_POST['rel_fields_list'] != '') {
 
-    if (isset($_REQUEST['rel_fields_list']) && $_REQUEST['rel_fields_list'] != '') {
-
-        $map = PMA_getForeigners($db, $table, '', 'both');
+        $map = $relation->getForeigners($db, $table, '', 'both');
 
         $relation_fields = array();
-        parse_str($_REQUEST['rel_fields_list'], $relation_fields);
+        parse_str($_POST['rel_fields_list'], $relation_fields);
 
         // loop for each relation cell
         /** @var array $relation_fields */
         foreach ($relation_fields as $cell_index => $curr_rel_field) {
             foreach ($curr_rel_field as $relation_field => $relation_field_value) {
                 $where_comparison = "='" . $relation_field_value . "'";
-                $dispval = PMA_getDisplayValueForForeignTableColumn(
+                $dispval = $insertEdit->getDisplayValueForForeignTableColumn(
                     $where_comparison, $map, $relation_field
                 );
 
                 $extra_data['relations'][$cell_index]
-                    = PMA_getLinkForRelationalDisplayField(
+                    = $insertEdit->getLinkForRelationalDisplayField(
                         $map, $relation_field, $where_comparison,
                         $dispval, $relation_field_value
                     );
             }
         }   // end of loop for each relation cell
     }
-    if (isset($_REQUEST['do_transformations'])
-        && $_REQUEST['do_transformations'] == true
+    if (isset($_POST['do_transformations'])
+        && $_POST['do_transformations'] == true
     ) {
         $edited_values = array();
-        parse_str($_REQUEST['transform_fields_list'], $edited_values);
+        parse_str($_POST['transform_fields_list'], $edited_values);
 
         if (! isset($extra_data)) {
             $extra_data = array();
@@ -406,8 +425,8 @@ if ($response->isAjax() && ! isset($_POST['ajax_page_request'])) {
         foreach ($mime_map as $transformation) {
             $column_name = $transformation['column_name'];
             foreach ($transformation_types as $type) {
-                $file = PMA_securePath($transformation[$type]);
-                $extra_data = PMA_transformEditedValues(
+                $file = Core::securePath($transformation[$type]);
+                $extra_data = $insertEdit->transformEditedValues(
                     $db, $table, $transformation, $edited_values, $file,
                     $column_name, $extra_data, $type
                 );
@@ -417,22 +436,22 @@ if ($response->isAjax() && ! isset($_POST['ajax_page_request'])) {
 
     // Need to check the inline edited value can be truncated by MySQL
     // without informing while saving
-    $column_name = $_REQUEST['fields_name']['multi_edit'][0][0];
+    $column_name = $_POST['fields_name']['multi_edit'][0][0];
 
-    PMA_verifyWhetherValueCanBeTruncatedAndAppendExtraData(
+    $insertEdit->verifyWhetherValueCanBeTruncatedAndAppendExtraData(
         $db, $table, $column_name, $extra_data
     );
 
     /**Get the total row count of the table*/
-    $extra_data['row_count'] = PMA_Table::countRecords(
-        $_REQUEST['db'], $_REQUEST['table']
+    $_table = new Table($_POST['table'], $_POST['db']);
+    $extra_data['row_count'] = $_table->countRecords();
+
+    $extra_data['sql_query'] = Util::getMessage(
+        $message,
+        $GLOBALS['display_query']
     );
 
-    $extra_data['sql_query']
-        = PMA_Util::getMessage($message, $GLOBALS['display_query']);
-
-    $response = PMA_Response::getInstance();
-    $response->isSuccess($message->isSuccess());
+    $response->setRequestStatus($message->isSuccess());
     $response->addJSON('message', $message);
     $response->addJSON($extra_data);
     exit;
@@ -445,8 +464,8 @@ if (! empty($return_to_sql_query)) {
     $GLOBALS['sql_query'] = $return_to_sql_query;
 }
 
+$scripts->addFile('vendor/jquery/additional-methods.js');
 $scripts->addFile('tbl_change.js');
-$scripts->addFile('big_ints.js');
 
 $active_page = $goto_include;
 
@@ -455,14 +474,12 @@ $active_page = $goto_include;
  * WHERE clause information so that tbl_change.php does not go back
  * to the current record
  */
-if (isset($_REQUEST['after_insert']) && 'new_insert' == $_REQUEST['after_insert']) {
-    unset($_REQUEST['where_clause']);
+if (isset($_POST['after_insert']) && 'new_insert' == $_POST['after_insert']) {
+    unset($_POST['where_clause']);
 }
 
 /**
  * Load target page.
  */
-require '' . PMA_securePath($goto_include);
+require '' . Core::securePath($goto_include);
 exit;
-
-?>
